Module: Easyop::Skip::ClassMethods
- Defined in:
- lib/easyop/skip.rb
Instance Method Summary collapse
- #_skip_predicate ⇒ Object
-
#skip?(ctx) ⇒ Boolean
Returns true if this step should be skipped for the given ctx.
- #skip_if(&block) ⇒ Object
Instance Method Details
#_skip_predicate ⇒ Object
12 13 14 |
# File 'lib/easyop/skip.rb', line 12 def _skip_predicate @_skip_predicate end |
#skip?(ctx) ⇒ Boolean
Returns true if this step should be skipped for the given ctx.
17 18 19 |
# File 'lib/easyop/skip.rb', line 17 def skip?(ctx) @_skip_predicate ? @_skip_predicate.call(ctx) : false end |
#skip_if(&block) ⇒ Object
8 9 10 |
# File 'lib/easyop/skip.rb', line 8 def skip_if(&block) @_skip_predicate = block end |